package com.younike.system.mapper;

import java.util.List;
import com.younike.system.domain.Goods;
import com.younike.system.domain.vo.GoodsVo;
import com.younike.system.param.GoodsParam;
import com.younike.system.param.GoodsQueryParam;
import org.apache.ibatis.annotations.Param;

/**
 * 商品Mapper接口
 *
 * @author elev
 * @date 2022-01-06
 */
public interface GoodsMapper {

    /**
     * 管理页面服务列表
     * @param param
     * @return
     */
    List<GoodsVo> pageList(GoodsQueryParam param);
    /**
     * 查询商品
     *
     * @param goodsId 商品主键
     * @return 商品
     */
    Goods selectGoodsByGoodsId(Long goodsId);

    /**
     * 查询商品列表
     *
     * @param goods 商品
     * @return 商品集合
     */
    List<Goods> selectGoodsList(Goods goods);

    /**
     * 新增商品
     *
     * @param goods 商品
     * @return 结果
     */
    int insertGoods(Goods goods);

    /**
     * 修改商品
     *
     * @param goods 商品
     * @return 结果
     */
    int updateGoods(Goods goods);

    /**
     * 删除商品
     *
     * @param goodsId 商品主键
     * @return 结果
     */
    int deleteGoodsByGoodsId(Long goodsId);

    /**
     * 批量删除商品
     *
     * @param goodsIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteGoodsByGoodsIds(Long[] goodsIds);

    /**
     * 查询服务人员产品列表
     */

    List<GoodsVo> seekCrewList(@Param("goods")GoodsParam goods);

    /**
     * 查询商家产品列表列表
     * @param goods
     * @return
     */
    List<GoodsVo> seekMerchantList(@Param("goods")GoodsParam goods);

    /**
     * 首页：商家主页
     * @param goods
     * @return
     */
    GoodsVo merchantGoods(@Param("goods")GoodsParam goods);

    /**
     * 首页：服务人员
     * @param goods
     * @return
     */
    GoodsVo serverGoods(@Param("goods")GoodsParam goods);
}
