package com.younike.system.service;

import java.util.List;

import com.younike.common.core.domain.AjaxResult;
import com.younike.system.domain.Goods;
import com.younike.system.domain.vo.GoodsFormVO;
import com.younike.system.domain.vo.GoodsVo;
import com.younike.system.param.GoodsParam;
import com.younike.system.param.GoodsQueryParam;

/**
 * 商品Service接口
 *
 * @author elev
 * @date 2022-01-06
 */
public interface IGoodsService {

    /**
     * 查询商品列表
     *
     * @param param 商品
     * @return 商品集合
     */
    List<GoodsVo> pageList(GoodsQueryParam param);
    /**
     * 商品信息保存
     * @param goodsFormVO
     * @return
     */
    int save(GoodsFormVO goodsFormVO);

    /**
     * 查询商品明细
     * @param goodsId
     * @return
     */
    GoodsFormVO detail(Long goodsId);

    /**
     * 查询商品
     *
     * @param goodsId 商品主键
     * @return 商品
     */
    Goods selectGoodsByGoodsId(Long goodsId);

    /**
     * 查询商品列表
     *
     * @param goods 商品
     * @return 商品集合
     */
    List<Goods> selectGoodsList(Goods goods);

    /**
     * 新增商品
     *
     * @param goods 商品
     * @return 结果
     */
    int insertGoods(Goods goods);

    /**
     * 修改商品
     *
     * @param goods 商品
     * @return 结果
     */
    int updateGoods(Goods goods);

    /**
     * 批量删除商品
     *
     * @param goodsIds 需要删除的商品主键集合
     * @return 结果
     */
    int deleteGoodsByGoodsIds(Long[] goodsIds);

    /**
     * 删除商品信息
     *
     * @param goodsId 商品主键
     * @return 结果
     */
    int deleteGoodsByGoodsId(Long goodsId);

    List<Goods> list(Goods goods);

    int remove(Long goodsId);

    int onShelf(Long goodsId);

    int offShelf(Long goodsId);
    AjaxResult merchantGoods(GoodsParam goods);

    /**
     * 首页：服务员主页
     * @param goods
     * @return
     */
    AjaxResult serverGoods(GoodsParam goods);

    /**
     * 搜索服务人员
     * @param goods
     * @return
     */
    List<GoodsVo> seekCrewList(GoodsParam goods);

    /**
     * 搜索商家
     * @param goods
     * @return
     */
    List<GoodsVo> seekMerchantList(GoodsParam goods);

}
