package com.younike.system.service;

import java.util.List;

import com.younike.common.core.domain.AjaxResult;
import com.younike.system.domain.Order;
import com.younike.system.domain.ServerTime;
import com.younike.system.domain.vo.DateSectionVO;
import com.younike.system.domain.vo.ServerTimeVo;
import com.younike.hlpay.dto.OrderParam;
import com.younike.system.param.PaymentParam;

/**
 * 服务人员服务时间Service接口
 *
 * @author elev
 * @date 2022-01-10
 */
public interface IServerTimeService {
    /**
     * 查询服务人员服务时间
     *
     * @param serverId 服务人员服务时间主键
     * @return 服务人员服务时间
     */
    ServerTime selectServerTimeByServerId(Long serverId);

    /**
     * 查询服务人员服务时间列表
     *
     * @param serverTime 服务人员服务时间
     * @return 服务人员服务时间集合
     */
    List<ServerTime> selectServerTimeList(ServerTime serverTime);

    /**
     * 新增服务人员服务时间
     *
     * @param serverTime 服务人员服务时间
     * @return 结果
     */
    int insertServerTime(ServerTime serverTime);

    /**
     * 修改服务人员服务时间
     *
     * @param serverTime 服务人员服务时间
     * @return 结果
     */
    int updateServerTime(ServerTime serverTime);

    /**
     * 批量删除服务人员服务时间
     *
     * @param serverIds 需要删除的服务人员服务时间主键集合
     * @return 结果
     */
    int deleteServerTimeByServerIds(Long[] serverIds);

    /**
     * 删除服务人员服务时间信息
     *
     * @param serverId 服务人员服务时间主键
     * @return 结果
     */
    int deleteServerTimeByServerId(Long serverId);

    ServerTime getServerTimeInfo(ServerTime serverTime);


    /**
     * 根据服务人员id查询服务人员工作时间数据
     * @param serverId
     * @return
     */
    ServerTimeVo getServerTime(Long serverId);

    /**
     * 根据服务人员id查询服务人员已经被预约的时间
     * @param serverId
     * @return
     */
    List<Order> getServerOrderTime(Long serverId);

    /**
     * @param serverId 服务人员ID
     * @return 服务人员服务时间选择列表
     */
    List<DateSectionVO> getServerTimeSections(Long serverId);

    /**
     * 查询预约的时间服务人员是否下班
     * @param param
     * @return
     */
    AjaxResult getServerWork(OrderParam param);


}
